@@ -2,13 +2,12 @@
 SEXP df_string;
 int LFE_GLOBAL_THREADS = 1;
 
-SEXP MY_threads(SEXP rt)
-{
-  if (LENGTH(rt) < 1)
-    return R_NilValue;
+SEXP MY_threads(SEXP rt) {
+  if (LENGTH(rt) < 1) return R_NilValue;
   LFE_GLOBAL_THREADS = INTEGER(rt)[0];
   return R_NilValue;
 }
+
 static R_CallMethodDef callMethods[] = {
     {"conncomp", (DL_FUNC)&MY_conncomp, 1},
     {"wwcomp", (DL_FUNC)&MY_wwcomp, 1},
@@ -28,8 +27,7 @@ static R_CallMethodDef callMethods[] = {
     //  {"threads", (DL_FUNC) &MY_threads, 1},
     {NULL, NULL, 0}};
 
-void attribute_visible R_init_lfe(DllInfo *info)
-{
+void attribute_visible R_init_lfe(DllInfo *info) {
   /* register our routines */
   (void)R_registerRoutines(info, NULL, callMethods, NULL, NULL);
   (void)R_useDynamicSymbols(info, FALSE);
@@ -38,10 +36,8 @@ void attribute_visible R_init_lfe(DllInfo *info)
   LFE_GLOBAL_THREADS = 1;
 }
 
-void attribute_visible R_unload_lfe(DllInfo *info)
-{
-  if (info != NULL)
-  {
-  }; // avoid pedantic warning about unused parameter
+void attribute_visible R_unload_lfe(DllInfo *info) {
+  if (info != NULL) {
+  };  // avoid pedantic warning about unused parameter
   (void)R_ReleaseObject(df_string);
 }
