@@ -1,3 +1,5 @@
+#include <inttypes.h>
+
 #include "lfe.h"
 
 #define USE_FC_LEN_T
@@ -5,40 +7,31 @@
 #define FCONE
 #endif
 
-SEXP MY_scalecols(SEXP mat, SEXP vec)
-{
-  if (!isMatrix(mat))
-    error("first argument should be a matrix");
+SEXP MY_scalecols(SEXP mat, SEXP vec) {
+  if (!isMatrix(mat)) error("first argument should be a matrix");
   mybigint_t col = ncols(mat), row = nrows(mat);
-  if (isMatrix(vec))
-  {
+  if (isMatrix(vec)) {
     if (row != nrows(vec))
       error("Rows of matrix should be the same as rows of vector");
     double *cmat = REAL(mat);
     double *cvec = REAL(AS_NUMERIC(vec));
-    for (mybigint_t j = 0; j < col; j++)
-    {
+    for (mybigint_t j = 0; j < col; j++) {
       double *cc = &cmat[j * row];
-      for (mybigint_t i = 0; i < row; i++)
-      {
+      for (mybigint_t i = 0; i < row; i++) {
         double tmp = 0.0;
-        for (int k = 0; k < ncols(vec); k++)
-          tmp += cc[i] * cvec[i + k * row];
+        for (int k = 0; k < ncols(vec); k++) tmp += cc[i] * cvec[i + k * row];
         cc[i] = tmp;
       }
     }
-  }
-  else
-  {
+  } else {
     if (row != LENGTH(vec))
-      error("length of vector %d is different from number of rows %d", LENGTH(vec), row);
+      error("length of vector %d is different from number of rows %" PRIdMAX,
+            LENGTH(vec), (intmax_t)row);
     double *cmat = REAL(mat);
     double *cvec = REAL(AS_NUMERIC(vec));
-    for (mybigint_t j = 0; j < col; j++)
-    {
+    for (mybigint_t j = 0; j < col; j++) {
       double *cc = &cmat[j * row];
-      for (mybigint_t i = 0; i < row; i++)
-        cc[i] *= cvec[i];
+      for (mybigint_t i = 0; i < row; i++) cc[i] *= cvec[i];
     }
   }
   return mat;
@@ -53,8 +46,7 @@ SEXP MY_scalecols(SEXP mat, SEXP vec)
   X + t(beta * t(Y)), so this is a utility to save some costly transposes.
   used in cgsolve()
  */
-SEXP MY_pdaxpy(SEXP inX, SEXP inY, SEXP inbeta)
-{
+SEXP MY_pdaxpy(SEXP inX, SEXP inY, SEXP inbeta) {
   mybigint_t col = ncols(inX), row = nrows(inX);
   if (col != ncols(inY) || row != nrows(inY))
     error("X and Y should have the same shape");
@@ -66,14 +58,12 @@ SEXP MY_pdaxpy(SEXP inX, SEXP inY, SEXP inbeta)
   SEXP res;
   PROTECT(res = allocMatrix(REALSXP, row, col));
   double *pres = REAL(res);
-  for (mybigint_t j = 0; j < col; j++)
-  {
+  for (mybigint_t j = 0; j < col; j++) {
     double b = beta[j];
     double *out = &pres[j * row];
     double *xin = &X[j * row];
     double *yin = &Y[j * row];
-    for (mybigint_t i = 0; i < row; i++)
-    {
+    for (mybigint_t i = 0; i < row; i++) {
       out[i] = xin[i] + b * yin[i];
     }
   }
@@ -85,8 +75,7 @@ SEXP MY_pdaxpy(SEXP inX, SEXP inY, SEXP inbeta)
   compute inner product pairwise of the columns of matrices X and Y
   This is diag(crossprod(X,Y)).
  */
-SEXP MY_piproduct(SEXP inX, SEXP inY)
-{
+SEXP MY_piproduct(SEXP inX, SEXP inY) {
   mybigint_t col = ncols(inX), row = nrows(inX);
   if (col != ncols(inY) || row != nrows(inY))
     error("X and Y should have the same shape");
@@ -95,13 +84,11 @@ SEXP MY_piproduct(SEXP inX, SEXP inY)
   SEXP res;
   PROTECT(res = allocVector(REALSXP, col));
   double *pres = REAL(res);
-  for (mybigint_t j = 0; j < col; j++)
-  {
+  for (mybigint_t j = 0; j < col; j++) {
     double *xin = &X[j * row];
     double *yin = &Y[j * row];
     pres[j] = 0.0;
-    for (mybigint_t i = 0; i < row; i++)
-    {
+    for (mybigint_t i = 0; i < row; i++) {
       pres[j] += xin[i] * yin[i];
     }
   }
@@ -110,27 +97,20 @@ SEXP MY_piproduct(SEXP inX, SEXP inY)
 }
 // copy-free dimnames<-
 
-SEXP MY_setdimnames(SEXP obj, SEXP nm)
-{
-  if (!isNull(obj))
-    setAttrib(obj, R_DimNamesSymbol, nm);
+SEXP MY_setdimnames(SEXP obj, SEXP nm) {
+  if (!isNull(obj)) setAttrib(obj, R_DimNamesSymbol, nm);
   return (R_NilValue);
 }
 
 /* Compute and return alpha * bread %*% meat %*% bread */
 
-SEXP MY_sandwich(SEXP inalpha, SEXP inbread, SEXP inmeat)
-{
+SEXP MY_sandwich(SEXP inalpha, SEXP inbread, SEXP inmeat) {
   double alpha = REAL(AS_NUMERIC(inalpha))[0];
-  if (!isMatrix(inbread))
-    error("bread must be a matrix");
-  if (!isMatrix(inmeat))
-    error("bread must be a matrix");
-  if (ncols(inbread) != nrows(inbread))
-    error("bread must be square matrix");
+  if (!isMatrix(inbread)) error("bread must be a matrix");
+  if (!isMatrix(inmeat)) error("bread must be a matrix");
+  if (ncols(inbread) != nrows(inbread)) error("bread must be square matrix");
 
-  if (ncols(inmeat) != nrows(inmeat))
-    error("meat must be square matrix");
+  if (ncols(inmeat) != nrows(inmeat)) error("meat must be square matrix");
 
   if (ncols(inmeat) != ncols(inbread))
     error("bread and meat must have the same size");
@@ -156,34 +136,28 @@ SEXP MY_sandwich(SEXP inalpha, SEXP inbread, SEXP inmeat)
 }
 
 // copy-free dsyrk C = beta*C + alpha * A' A
-SEXP MY_dsyrk(SEXP inbeta, SEXP inC, SEXP inalpha, SEXP inA)
-{
+SEXP MY_dsyrk(SEXP inbeta, SEXP inC, SEXP inalpha, SEXP inA) {
   double beta = REAL(AS_NUMERIC(inbeta))[0];
   double alpha = REAL(AS_NUMERIC(inalpha))[0];
-  if (!isMatrix(inC))
-    error("C must be a matrix");
-  if (!isMatrix(inA))
-    error("A must be a matrix");
+  if (!isMatrix(inC)) error("C must be a matrix");
+  if (!isMatrix(inA)) error("A must be a matrix");
 
-  if (ncols(inC) != nrows(inC))
-  {
+  if (ncols(inC) != nrows(inC)) {
     error("C must be a square matrix, it is %d x %d", nrows(inC), ncols(inC));
   }
   int N = nrows(inC);
   double *C = REAL(inC);
-  if (ncols(inA) != ncols(inC))
-  {
-    error("A (%d x %d) must have the same number of columns as C (%d x %d)", nrows(inA), ncols(inA), nrows(inC), nrows(inC));
+  if (ncols(inA) != ncols(inC)) {
+    error("A (%d x %d) must have the same number of columns as C (%d x %d)",
+          nrows(inA), ncols(inA), nrows(inC), nrows(inC));
   }
   int K = nrows(inA);
   double *A = REAL(inA);
   F77_CALL(dsyrk)
   ("U", "T", &N, &K, &alpha, A, &K, &beta, C, &N FCONE FCONE);
   // fill in the lower triangular part
-  for (mybigint_t row = 0; row < N; row++)
-  {
-    for (mybigint_t col = 0; col < row; col++)
-    {
+  for (mybigint_t row = 0; row < N; row++) {
+    for (mybigint_t col = 0; col < row; col++) {
       C[col * N + row] = C[row * N + col];
     }
   }
@@ -191,17 +165,14 @@ SEXP MY_dsyrk(SEXP inbeta, SEXP inC, SEXP inalpha, SEXP inA)
 }
 
 // debugging memory copy
-SEXP MY_address(SEXP x)
-{
+SEXP MY_address(SEXP x) {
   char chr[30];
   snprintf(chr, sizeof(chr), "adr=%p, named=%d", (void *)x, NAMED(x));
   return (mkString(chr));
 }
 
-SEXP MY_named(SEXP x, SEXP n)
-{
-  if (isNull(n))
-  {
+SEXP MY_named(SEXP x, SEXP n) {
+  if (isNull(n)) {
     // return NAMED status
     SEXP res = allocVector(INTSXP, 1);
     PROTECT(res);
@@ -217,19 +188,16 @@ SEXP MY_named(SEXP x, SEXP n)
 }
 
 /* Trickery to check for interrupts when using threads */
-static void chkIntFn(void *dummy)
-{
-  if (dummy == NULL)
-  {
-  }; // avoid pedantic warning about unused parameter
+static void chkIntFn(void *dummy) {
+  if (dummy == NULL) {
+  };  // avoid pedantic warning about unused parameter
   R_CheckUserInterrupt();
 }
 
 /* this will call the above in a top-level context so it won't
    longjmp-out of context */
 
-extern int checkInterrupt(void)
-{
+extern int checkInterrupt(void) {
   return (R_ToplevelExec(chkIntFn, NULL) == 0);
 }
 
@@ -241,46 +209,36 @@ extern int checkInterrupt(void)
 static char *msgstack[MSGLIM];
 static int msgptr;
 
-extern void initmsg(void)
-{
-  msgptr = 0;
-}
+extern void initmsg(void) { msgptr = 0; }
 /* Craft our own strdup, it's not supported everywhere */
-static char *mystrdup(char *s)
-{
+static char *mystrdup(char *s) {
   char *sc = (char *)malloc(strlen(s) + 1);
-  if (sc != NULL)
-    strcpy(sc, s);
+  if (sc != NULL) strcpy(sc, s);
   return (sc);
 }
-void pushmsg(char *s, LOCK_T lock)
-{
+void pushmsg(char *s, LOCK_T lock) {
 #ifdef NOTHREADS
   REprintf(s);
 #else
   LOCK(lock);
-  if (msgptr < MSGLIM)
-  {
+  if (msgptr < MSGLIM) {
     msgstack[msgptr++] = mystrdup(s);
   }
   UNLOCK(lock);
 #endif
 }
 
-void printmsg(LOCK_T lock)
-{
+void printmsg(LOCK_T lock) {
 #ifdef NOTHREADS
   return;
 #else
   char *s;
   int i;
   LOCK(lock);
-  for (i = 0; i < msgptr; i++)
-  {
+  for (i = 0; i < msgptr; i++) {
     s = msgstack[i];
-    if (s != NULL)
-    {
-      REprintf(s);
+    if (s != NULL) {
+      REprintf("%s", s);
       free(s);
     }
   }
